Mutex

Struct Mutex 

pub struct Mutex<T>
where T: ?Sized,
{ state: AtomicUsize, waiters: Mutex<Slab<Waiter>>, value: UnsafeCell<T>, }
A futures-aware mutex.

Fairness

This mutex provides no fairness guarantees. Tasks may not acquire the mutex in the order that they requested the lock, and it’s possible for a single task which repeatedly takes the lock to starve other tasks, which may be left waiting indefinitely.

Fields

state: AtomicUsizewaiters: Mutex<Slab<Waiter>>value: UnsafeCell<T>

Implementations



impl<T> Mutex<T>

pub const fn new(t: T) -> Mutex<T>

Creates a new futures-aware mutex.

pub fn into_inner(self) -> T

Consumes this mutex, returning the underlying data.

Examples
use futures::lock::Mutex;

let mutex = Mutex::new(0);
assert_eq!(mutex.into_inner(), 0);


impl<T> Mutex<T>
where T: ?Sized,

pub fn try_lock(&self) -> Option<MutexGuard<'_, T>>

Attempt to acquire the lock immediately.

If the lock is currently held, this will return None.

pub fn try_lock_owned(self: &Arc<Mutex<T>>) -> Option<OwnedMutexGuard<T>>

Attempt to acquire the lock immediately.

If the lock is currently held, this will return None.

pub fn lock(&self) -> MutexLockFuture<'_, T>

Acquire the lock asynchronously.

This method returns a future that will resolve once the lock has been successfully acquired.

pub fn lock_owned(self: Arc<Mutex<T>>) -> OwnedMutexLockFuture<T>

Acquire the lock asynchronously.

This method returns a future that will resolve once the lock has been successfully acquired.

pub fn get_mut(&mut self) -> &mut T

Returns a mutable reference to the underlying data.

Since this call borrows the Mutex mutably, no actual locking needs to take place – the mutable borrow statically guarantees no locks exist.

Examples
use futures::lock::Mutex;

let mut mutex = Mutex::new(0);
*mutex.get_mut() = 10;
assert_eq!(*mutex.lock().await, 10);